SegmentCollector

Struct SegmentCollector 

pub struct SegmentCollector<'a> { /* private fields */ }
State for processing glyph’s outline segment.

This can process incoming glyph segment by splitting quadratic and cubic bezier into flat lines, and also tag each segment with at least two R, G or B color (according to Chlumsky’s algorithm).

It is necessary to store collected segments in a Vec. This type does not allocate the vec directly, but instead accepts an exclusive reference to the Vec, so the vec can be reused between different glyphs.

Implementations

Source

impl<'a> SegmentCollector<'a>

pub fn move_to(&mut self, x: f32, y: f32)

Emit a command to begin a new subpath at (x, y).

pub fn line_to(&mut self, x: f32, y: f32)

Emit a line segment from the current point to (x, y).

pub fn quad_to(&mut self, cx0: f32, cy0: f32, x: f32, y: f32)

Emit a quadratic bezier segment from the current point with a control point at (cx0, cy0) and ending at (x, y).

pub fn curve_to( &mut self, cx0: f32, cy0: f32, cx1: f32, cy1: f32, x: f32, y: f32, )

Emit a cubic bezier segment from the current point with control points at (cx0, cy0) and (cx1, cy1) and ending at (x, y).

pub fn close(&mut self)

Emit a command to close the current subpath.

pub fn set_reversed(&mut self, reversed: bool)

Reverse the direction of all subsequently collected subpaths.

Set this before collecting the outline. Pass in true for CFF/CFF2 glyphs and false for GLYF.